pydash
******

|version| |build| |coveralls| |license|

The kitchen sink of Python utility libraries for doing "stuff" in a functional way. Based on the `Lo-Dash <http://lodash.com/>`_  Javascript library.

Note
====

Looking for a library that is more memory efficient and better suited for large datasets? Check out `fnc <https://github.com/dgilland/fnc>`_! It's built around generators and iteration and has iteratee-first function signatures.


Links
=====

- Project: https://github.com/dgilland/pydash
- Documentation: http://pydash.readthedocs.org
- PyPi: https://pypi.python.org/pypi/pydash/
- Github Actions: https://github.com/dgilland/pydash/actions


.. |version| image:: http://img.shields.io/pypi/v/pydash.svg?style=flat-square
    :target: https://pypi.python.org/pypi/pydash/

.. |build| image:: https://img.shields.io/github/workflow/status/dgilland/pydash/Main/master?style=flat-square
    :target: https://github.com/dgilland/pydash/actions

.. |coveralls| image:: http://img.shields.io/coveralls/dgilland/pydash/master.svg?style=flat-square
    :target: https://coveralls.io/r/dgilland/pydash

.. |license| image:: http://img.shields.io/pypi/l/pydash.svg?style=flat-square
    :target: https://pypi.python.org/pypi/pydash/
